@@ -6,12 +6,13 @@ use diagnostics;
 
 # ABSTRACT: Data store to support Net::LDAP::SimpleServer
 
-our $VERSION = '0.0.14';    # VERSION
+our $VERSION = '0.0.15';    # VERSION
 
 use 5.010;
 use Carp qw/carp croak/;
 use UNIVERSAL::isa;
 use Scalar::Util qw(blessed reftype);
+
 use Net::LDAP::LDIF;
 
 sub new {
@@ -94,19 +95,11 @@ sub _load_ldif {
     return \@sortedlist;
 }
 
-sub filter {
-    my ( $self, $sub ) = @_;
-    return () unless $self->{list};
-
-    my @list = @{ $self->{list} };
-
-    foreach my $index ( 0 .. $#list ) {
-        delete $list[$index] unless $sub->( $list[$index] );
-    }
-    return @list;
+sub list {    ## no critic
+    return $_[0]->{list};
 }
 
-1;    # Magic true value required at end of module
+1;            # Magic true value required at end of module
 
 
 
@@ -120,7 +113,7 @@ Net::LDAP::SimpleServer::LDIFStore - Data store to support Net::LDAP::SimpleServ
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 SYNOPSIS
 
@@ -135,11 +128,6 @@ version 0.0.14
     my $ldif = Net::LDAP::LDIF->new( "file.ldif" );
     my $store = Net::LDAP::SimpleServer::LDIFStore->new($ldif);
 
-    my $result = $store->filter( sub {
-      $a = shift;
-      $a->get_value('cn') =~ m/joe/i;
-    } );
-
 =head1 DESCRIPTION
 
 This module provides an interface between Net::LDAP::SimpleServer and a
@@ -148,16 +136,15 @@ LDIF file where the data is stored.
 As of now, this interface is quite simple, and so is the underlying data
 structure, but this can be easily improved in the future.
 
-=head1 CONSTRUCTOR
+=head1 METHODS
 
-=over
-
-=item new()
+=head2 new()
 
 Creates a store with no data in it. It cannot be really used like that, you
-B<must> C<< load() >> some data in it first.
+B<must> C<< load() >> some data with the C<load()> method before being able
+to use it.
 
-=item new( FILE )
+=head2 new( FILE )
 
 Create the data store by reading FILE, which may be the name of a file or an
 already open filehandle. It is passed directly to
@@ -166,7 +153,7 @@ L<<  Net::LDAP::LDIF >>.
 Constructor. Expects either: a filename, a file handle, a hash reference or
 a reference to a C<Net::LDAP::LDIF> object.
 
-=item new( HASHREF )
+=head2 new( HASHREF )
 
 Create the data store using the parameters in HASHREF. The associative-array
 referenced by HASHREF B<must> contain a key named C<< ldif >>, which must
@@ -175,74 +162,22 @@ C<< ldif_options >>, which may contain optional parameters used in the
 3-parameter version of the C<Net::LDAP::LDIF> constructor. The LDIF file will
 be used for reading the data.
 
-=item new( LDIF )
+=head2 new( LDIF )
 
 Uses an existing C<< Net::LDAP::LDIF >> as the source for the directory data.
 
-=back
-
-=head1 METHODS
-
-=over
-
-=item load( PARAM )
+=head2 load( PARAM )
 
 Loads data from a source specified by PARAM. The argument may be in any of the
 forms accepted by the constructor, except that it B<must> be specified.
 
-=item ldif()
+=head2 ldif()
 
 Returns the underlying C<< Net::LDAP::LDIF >> object.
 
-=item filter( SUBREF )
+=head2 list
 
-Returns a list of entries for which the function referenced by SUBREF returns
-C<true>.
-
-=back
-
-=for head1 DIAGNOSTICS
-
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-    =over
-    =item C<< Error message here, perhaps with %s placeholders >>
-    [Description of error here]
-    =item C<< Another error message here >>
-    [Description of error here]
-    [Et cetera, et cetera]
-    =back
-
-=head1 CONFIGURATION AND ENVIRONMENT
-
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-
-Net::LDAP::SimpleServer requires no configuration files or environment variables.
-
-=head1 DEPENDENCIES
-
-L<< UNIVERSAL::isa >>
-
-L<< Scalar::Util >>
-
-L<< Net::LDAP::LDIF >>
-
-=head1 INCOMPATIBILITIES
-
-None reported.
-
-=head1 BUGS AND LIMITATIONS
-
-This store does not yet support writing to a LDIF file, which makes the
-C<< Net::LDAP::SimpleServer >> a read-only server.
+Returns the list of entries.
 
 =head1 SEE ALSO
 
@@ -269,10 +204,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
