@@ -7,7 +7,7 @@ use common::sense;
 
 # ABSTRACT: LDAP protocol handler used with Net::LDAP::SimpleServer
 
-our $VERSION = '0.0.14';    # VERSION
+our $VERSION = '0.0.15';    # VERSION
 
 use Net::LDAP::Server;
 use base 'Net::LDAP::Server';
@@ -16,6 +16,8 @@ use fields qw(store root_dn root_pw);
 use Carp;
 use Net::LDAP::LDIF;
 use Net::LDAP::Util qw{canonical_dn};
+use Net::LDAP::FilterMatch;
+
 use Scalar::Util qw{blessed reftype looks_like_number};
 use UNIVERSAL::isa;
 
@@ -62,7 +64,6 @@ sub new {
 
     croak 'Must pass root_dn!' unless exists $params->{root_dn};
 
-    #my $canon_dn;
     croak 'Invalid root DN'
       unless my $canon_dn = canonical_dn( $params->{root_dn} );
 
@@ -74,6 +75,16 @@ sub new {
     return $self;
 }
 
+sub unbind {
+    my $self = shift;
+
+    $self->{store}   = undef;
+    $self->{root_dn} = undef;
+    $self->{root_pw} = undef;
+
+    return _make_result(qw/LDAP_SUCCESS/);
+}
+
 sub bind {    ## no critic
 
     #    my $r = _bind(@_);
@@ -90,6 +101,7 @@ sub bind {    ## no critic
     return $ok unless $request->{name};
 
     #print STDERR qq{not anonymous\n};
+    # As of now, accepts only simple authentication
     return _make_result(qw/LDAP_AUTH_UNKNOWN/)
       unless exists $request->{authentication}->{simple};
 
@@ -113,13 +125,28 @@ sub bind {    ## no critic
     return $ok;
 }
 
+sub _match {
+    my ( $filter_spec, $elems ) = @_;
+
+    my $f = bless $filter_spec, 'Net::LDAP::Filter';
+    return [ grep { $f->match($_) } @{$elems} ];
+}
+
 sub search {
     my ( $self, $request ) = @_;
 
-    print STDERR '=' x 70 . "\n";
-    print STDERR Dumper($request);
+    my $list   = $self->{store}->list;
+    my $basedn = $request->{baseObject};
 
-    return _make_result(qw/LDAP_SUCCESS/);
+    #print STDERR '=' x 50 . "\n";
+    #print STDERR Dumper($request);
+    #print STDERR Dumper($list);
+
+    my $res = _match( $request->{filter}, $list );
+
+    #print STDERR Dumper($res);
+
+    return ( _make_result(qw/LDAP_SUCCESS/), @{$res} );
 }
 
 1;    # Magic true value required at end of module
@@ -135,7 +162,7 @@ Net::LDAP::SimpleServer::ProtocolHandler - LDAP protocol handler used with Net::
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 SYNOPSIS
 
@@ -155,126 +182,25 @@ This module provides an interface between Net::LDAP::SimpleServer and the
 underlying data store. Currently only L<Net::LDAP::SimpleServer::LDIFStore>
 is available.
 
-=head1 NAME
+=head1 METHODS
 
-=head1 CONSTRUCTOR
-
-=over
-
-=item new( OPTIONS, IOHANDLES )
+=head2 new( OPTIONS, IOHANDLES )
 
 Creates a new handler for the LDAP protocol, using STORE as the backend
 where the directory data is stored. The rest of the IOHANDLES are the same
 as in the L<Net::LDAP::Server> module.
 
-=back
+=head2 unbind()
 
-=head1 METHODS
+Unbinds the connection to the server.
 
-=over
-
-=item bind( REQUEST )
+=head2 bind( REQUEST )
 
 Handles a bind REQUEST from the LDAP client.
 
-=item search( REQUEST )
+=head2 search( REQUEST )
 
-Performs a search in the data store
-
-=back
-
-=for head1 DIAGNOSTICS
-
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-    =over
-    =item C<< Error message here, perhaps with %s placeholders >>
-    [Description of error here]
-    =item C<< Another error message here >>
-    [Description of error here]
-    [Et cetera, et cetera]
-    =back
-
-=head1 CONFIGURATION AND ENVIRONMENT
-
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-
-Net::LDAP::SimpleServer::ProtocolHandler requires no configuration files or environment variables.
-
-=head1 DEPENDENCIES
-
-L<< common::sense >>
-
-L<< Net::LDAP::Server >>
-
-L<< Carp >>;
-
-L<< Net::LDAP::LDIF >>
-
-L<< Net::LDAP::Util >>
-
-L<< Scalar::Util >>
-
-L<< UNIVERSAL::isa >>
-
-L<< Net::LDAP::Constant >>
-
-=head1 INCOMPATIBILITIES
-
-None reported.
-
-=head1 BUGS AND LIMITATIONS
-
-This store does not yet support writing to a LDIF file, which makes the
-C<< Net::LDAP::SimpleServer >> a read-only server.
-
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-net-ldap-simpleserver@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 AUTHOR
-
-Alexei Znamensky  C<< <russoz@cpan.org> >>
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2010, Alexei Znamensky C<< <russoz@cpan.org> >>. All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+Performs a search in the data store.
 
 =head1 SEE ALSO
 
@@ -301,10 +227,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
